var path = require('path')
const ExtractTextPlugin = require('extract-text-webpack-plugin')

module.exports = {
  entry: {
    app: './src/main.js'
  },
  output: {
    path: path.resolve(__dirname, '../dist/static'),
    publicPath: 'static/',
    filename: '[name].js'
  },
  resolve: {
    extensions: ['.js', '.vue'],
    modules: [
      path.resolve(__dirname, 'src'),
      'node_modules'
    ]
  },
  resolveLoader: {
    modules: [
      path.join(__dirname, 'loaders'),
      'node_modules'
    ]
  },
  module: {
    loaders: [
      {
        test: /\.vue$/,
        loader: 'vue-loader',
        options: {
          loaders: {
            // 将所有的样式提取到一个文件中，而不是将其注入到JavaScript文件中
            // 注意，这里提取样式的loader也需要使用ExtractTextPlugin.loader
            css: ExtractTextPlugin.extract({
              use: 'css-loader',
              fallback: 'vue-style-loader'
            }),
            less: ExtractTextPlugin.extract({
              use: ['css-loader', 'less-loader'],
              fallback: 'vue-style-loader'
            }),
            stylus: ExtractTextPlugin.extract({
              use: ['css-loader', 'stylus-loader'],
              fallback: 'vue-style-loader'
            }),
            sass: ExtractTextPlugin.extract({
              use: ['css-loader', 'sass-loader'],
              fallback: 'vue-style-loader'
            })
          }
        }
      },
      {
        test: /\.js$/,
        loader: 'babel-loader',
        include: [
          /src/,
          /build/,
          /examples/,
          /singlepage/,
          /test/,
          /node_modules\/vue-client\/src/,
          /node_modules\/vue-strap\/src/,
          /node_modules\/system-clients\/src/,
          /node_modules\/ldap-clients\/src/,
          /node_modules\/sale-client\/src/,
          /node_modules\/manage-client\/src/,
          /node_modules\/address-client\/src/,
          /node_modules\/apply-clients\/src/,
          /node_modules\/telephone-clients\/src/,
          /node_modules\/safecheck-client\/src/,
          /node_modules\/webmeter-client\/src/,
          /node_modules\/material-client\/src/,
          /node_modules\/weixin-manage-client-wsd\/src/,
          /node_modules\/annunciator-client\/src/
        ]
      },
      {
        test: /\.html$/,
        loader: 'vue-html-loader'
      },
      {
        test: /\.css$/,
        loader: ExtractTextPlugin.extract({
          use: 'css-loader',
          fallback: 'vue-style-loader'
        })
      },
      {
        test: /\.less$/,
        loader: ExtractTextPlugin.extract({
          use: ['css-loader', 'less-loader'],
          fallback: 'vue-style-loader'
        })
      },
      {
        test: /\.stylus$/,
        loader: ExtractTextPlugin.extract({
          use: ['css-loader', 'stylus-loader'],
          fallback: 'vue-style-loader'
        })
      },
      {
        test: /\.sass$/,
        loader: ExtractTextPlugin.extract({
          use: ['css-loader', 'sass-loader'],
          fallback: 'vue-style-loader'
        })
      },
      {
        test: /\.(png|jpg|gif|svg|woff2?|eot|ttf)(\?.*)?$/,
        loader: 'url-loader',
        query: {
          limit: 10000,
          name: 'static/[name].[ext]?[hash:7]'
        }
      }
    ]
  },
  plugins: [
  ]
}
